package de.mdelab.mlsdm.diagram.custom.edit.parts;


import org.eclipse.draw2d.RoundedRectangle;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gmf.runtime.notation.View;

import de.mdelab.mlsdm.diagram.edit.parts.ResizableFlowLayout;
import de.mdelab.mlsdm.diagram.edit.parts.StoryPatternEditPart;
import de.mdelab.mlstorypatterns.StoryPattern;

public class CustomStoryPatternEditPart extends StoryPatternEditPart {

	public CustomStoryPatternEditPart( final View p_view ) {
		super( p_view );
	}

	@Override
	protected void handleNotificationEvent( final Notification p_notification ) {
		if ( p_notification.getNotifier() instanceof StoryPattern )	{
			repaint();
		}
		
		super.handleNotificationEvent( p_notification );
	}

	@Override
	protected void refreshVisuals()	{
		super.refreshVisuals();
		
		repaint();
	}

	private void repaint() {
		try{
			ResizableFlowLayout lay = new ResizableFlowLayout();
			getPrimaryShape().getParent().getParent().getParent().setLayoutManager(lay);
			getPrimaryShape().getParent().getParent().setLayoutManager(lay); 
			
			/* DB: Is the following setAlpha(1) instruction really needed? The purpose of this code seems to be to size the figure according to the number of constraints to be displayed.
			 The alpha parameter is related to the transparency of the shape and for some reason such parameter value causes to hide all elements rendered after a story 
			 pattern has been rendered during the export to image function, specifically for the png, pdf and jpeg formats (see Issue #1062). For the other formats, another graphics
			 rendered is used and this parameter does not seem to have an effect. */
			//getPrimaryShape().setAlpha(1);
			
			
			getPrimaryShape().setMinimumSize(new Dimension(0, 0));
			
			// Constraint's EditPart-size calculated with number of constraints 
			Dimension d = ((RoundedRectangle) getPrimaryShape().getChildren().get(0)).getPreferredSize();
			EObject ep = ((View) getModel()).getElement();
			int size = ((StoryPattern)ep).getConstraints().size();
			((RoundedRectangle) getPrimaryShape().getChildren().get(0)).setPreferredSize(new Dimension(d.width,16*size+16));
		}
		catch(ClassCastException cce){
			cce.printStackTrace();
		}
	}
}
